@@ -38,6 +38,8 @@
 
 #include "debug.h"
 
+#define ZERO_PREC 1e-10
+
 double mat_get_determinant_d3(SPGCONST double a[3][3])
 {
   return a[0][0] * (a[1][1] * a[2][2] - a[1][2] * a[2][1])
@@ -424,10 +426,13 @@ int mat_Nint(const double a)
 
 double mat_Dmod1(const double a)
 {
-  if (a < 0.0)
-    return a + 1.0 - (int) a;
+  double b;
+  b = a - mat_Nint(a);
+
+  if (b < 0.0 - ZERO_PREC)
+    return b + 1.0;
   else
-    return a - (int) a;
+    return b;
 }
 
 MatINT * mat_alloc_MatINT(const int size)
